FXOR_R

Type Alias FXOR_R 

pub type FXOR_R = R<bool, FXOR_A>;
Reader of field FXOR

Aliased Type

pub struct FXOR_R { /* private fields */ }

Implementations

Source

impl FXOR_R

pub fn variant(&self) -> FXOR_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1