INT5_R

Type Alias INT5_R 

pub type INT5_R = R<bool, INT5_A>;
Reader of field INT5

Aliased Type

pub struct INT5_R { /* private fields */ }

Implementations

Source

impl INT5_R

pub fn variant(&self) -> INT5_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1