RAMRDY_R

Type Alias RAMRDY_R 

pub type RAMRDY_R = R<bool, RAMRDY_A>;
Reader of field RAMRDY

Aliased Type

pub struct RAMRDY_R { /* private fields */ }

Implementations

Source

impl RAMRDY_R

pub fn variant(&self) -> RAMRDY_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1