SWAP_R

Type Alias SWAP_R 

pub type SWAP_R = R<bool, SWAP_A>;
Reader of field SWAP

Aliased Type

pub struct SWAP_R { /* private fields */ }

Implementations

Source

impl SWAP_R

pub fn variant(&self) -> SWAP_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1