TOFDIR_R

Type Alias TOFDIR_R 

pub type TOFDIR_R = R<bool, TOFDIR_A>;
Reader of field TOFDIR

Aliased Type

pub struct TOFDIR_R { /* private fields */ }

Implementations

Source

impl TOFDIR_R

pub fn variant(&self) -> TOFDIR_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1