pub struct PHBPOL_W<'a> { /* private fields */ }Expand description
Write proxy for field PHBPOL
Implementations
Sourceimpl<'a> PHBPOL_W<'a>
impl<'a> PHBPOL_W<'a>
Sourcepub fn _0(self) -> &'a mut W
pub fn _0(self) -> &'a mut W
Normal polarity. Phase B input signal is not inverted before identifying the rising and falling edges of this signal.