SWSYNC_R

Type Alias SWSYNC_R 

pub type SWSYNC_R = R<bool, SWSYNC_A>;
Reader of field SWSYNC

Aliased Type

pub struct SWSYNC_R { /* private fields */ }

Implementations

Source

impl SWSYNC_R

pub fn variant(&self) -> SWSYNC_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1