TOFDIR_A

Enum TOFDIR_A 

pub enum TOFDIR_A {
    _0 = 0,
    _1 = 1,
}
Timer Overflow Direction In Quadrature Decoder Mode

Value on reset: 0

Variants



_0 = 0

0: TOF bit was set on the bottom of counting. There was an FTM counter decrement and FTM counter changes from its minimum value (CNTIN register) to its maximum value (MOD register).



_1 = 1

1: TOF bit was set on the top of counting. There was an FTM counter increment and FTM counter changes from its maximum value (MOD register) to its minimum value (CNTIN register).