AVLP_R

Type Alias AVLP_R 

pub type AVLP_R = R<bool, AVLP_A>;
Reader of field AVLP

Aliased Type

pub struct AVLP_R { /* private fields */ }

Implementations

Source

impl AVLP_R

pub fn variant(&self) -> AVLP_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1