pub enum NF_A {
_0 = 0,
_1 = 1,
}Expand description
Noise Flag
Value on reset: 0
Variants
_0 = 0
0: No noise detected since the last time this flag was cleared. If the receive buffer has a depth greater than 1 then there may be data in the receiver buffer that was received with noise.
_1 = 1
1: At least one dataword was received with noise detected since the last time the flag was cleared.