ILT_R

Type Alias ILT_R 

pub type ILT_R = R<bool, ILT_A>;
Reader of field ILT

Aliased Type

pub struct ILT_R { /* private fields */ }

Implementations

Source

impl ILT_R

pub fn variant(&self) -> ILT_A

Get enumerated values variant

pub fn is_0(&self) -> bool

Checks if the value of the field is _0

pub fn is_1(&self) -> bool

Checks if the value of the field is _1