MAEN2_A

Enum MAEN2_A 

pub enum MAEN2_A {
    _0 = 0,
    _1 = 1,
}
Match Address Mode Enable 2

Value on reset: 0

Variants



_0 = 0

0: All data received is transferred to the data buffer if MAEN1 is cleared.



_1 = 1

1: All data received with the most significant bit cleared, is discarded. All data received with the most significant bit set, is compared with contents of MA2 register. If no match occurs, the data is discarded. If a match occurs, data is transferred to the data buffer. This field must be cleared when C7816[ISO7816E] is set/enabled.