pub enum MSBF_A {
_0 = 0,
_1 = 1,
}Expand description
Most Significant Bit First
Value on reset: 0
Variants
_0 = 0
0: LSB (bit0) is the first bit that is transmitted following the start bit. Further, the first bit received after the start bit is identified as bit0.
_1 = 1
1: MSB (bit8, bit7 or bit6) is the first bit that is transmitted following the start bit, depending on the setting of C1[M] and C1[PE]. Further, the first bit received after the start bit is identified as bit8, bit7, or bit6, depending on the setting of C1[M] and C1[PE].