R

Type Alias R 

pub type R = R<u8, ERRSTAT>;
Reader of register ERRSTAT

Aliased Type

pub struct R { /* private fields */ }

Implementations

Source

impl R

pub fn piderr(&self) -> PIDERR_R

Bit 0 - This bit is set when the PID check field fails.

pub fn crc5eof(&self) -> CRC5EOF_R

Bit 1 - This error interrupt has two functions

pub fn crc16(&self) -> CRC16_R

Bit 2 - This bit is set when a data packet is rejected due to a CRC16 error.

pub fn dfn8(&self) -> DFN8_R

Bit 3 - This bit is set if the data field received was not 8 bits in length

pub fn btoerr(&self) -> BTOERR_R

Bit 4 - This bit is set when a bus turnaround timeout error occurs

pub fn dmaerr(&self) -> DMAERR_R

Bit 5 - This bit is set if the USB Module has requested a DMA access to read a new BDT but has not been given the bus before it needs to receive or transmit data

pub fn btserr(&self) -> BTSERR_R

Bit 7 - This bit is set when a bit stuff error is detected