pub type FXOR_R = R<bool, FXOR_A>;
Reader of field FXOR
FXOR
pub struct FXOR_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1