pub type INT5_R = R<bool, INT5_A>;
Reader of field INT5
INT5
pub struct INT5_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1