pub type RAMRDY_R = R<bool, RAMRDY_A>;
Reader of field RAMRDY
RAMRDY
pub struct RAMRDY_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1