pub type SWAP_R = R<bool, SWAP_A>;
Reader of field SWAP
SWAP
pub struct SWAP_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1