pub type SWSYNC_R = R<bool, SWSYNC_A>;
Reader of field SWSYNC
SWSYNC
pub struct SWSYNC_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1