pub type AVLP_R = R<bool, AVLP_A>;
Reader of field AVLP
AVLP
pub struct AVLP_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1