pub type ILT_R = R<bool, ILT_A>;
Reader of field ILT
ILT
pub struct ILT_R { /* private fields */ }
Get enumerated values variant
Checks if the value of the field is _0
_0
Checks if the value of the field is _1
_1