pub type R = R<u8, ERRSTAT>;Expand description
Reader of register ERRSTAT
Aliased Type
pub struct R { /* private fields */ }Implementations
Sourceimpl R
impl R
Sourcepub fn crc16(&self) -> CRC16_R
pub fn crc16(&self) -> CRC16_R
Bit 2 - This bit is set when a data packet is rejected due to a CRC16 error.
Sourcepub fn dfn8(&self) -> DFN8_R
pub fn dfn8(&self) -> DFN8_R
Bit 3 - This bit is set if the data field received was not 8 bits in length
Sourcepub fn btoerr(&self) -> BTOERR_R
pub fn btoerr(&self) -> BTOERR_R
Bit 4 - This bit is set when a bus turnaround timeout error occurs